@@ -22,7 +22,7 @@ AdaBelief divides by the exponential mean of variance.
 m_t &\leftarrow \beta_1 m_{t-1} + (1 - \beta_1) \cdot g_t \\
 \color{cyan}{s_t} &\color{cyan}{\leftarrow} \color{cyan}{\beta_2 s_{t-1} + (1 - \beta_2) \cdot (g_t - m_t)^2} \\
 \hat{m}_t &\leftarrow \frac{m_t}{1-\beta_1^t} \\
-\color{cyan}{\hat{s}_t} &\color{cyan}{\leftarrow} \color{cyan}{\frac{s_t}{1-\beta_2^t}} \\
+\color{cyan}{\hat{s}_t} &\color{cyan}{\leftarrow} \frac{\color{cyan}{s_t} + \color{red}{\epsilon}}{\color{cyan}{1-\beta_2^t}} \\
 \theta_t &\leftarrow \theta_{t-1} - \alpha \cdot \frac{\hat{m}_t}{\sqrt{\color{cyan}{\hat{s}_t}} + \epsilon}
 \end{align}
 
@@ -150,8 +150,10 @@ class AdaBelief(RAdam):
         state['step'] += 1
 
         if not self.rectify:
-            # Perform *Adam* update, defined in [`adam.py`](adam.html).
-            self.adam_update(state, group, param, m, s)
+            # Perform *Adam* update, defined in [`adam.py`](adam.html), with
+            # $\color{cyan}{s_t} + \color{red}{\epsilon}$ in place of $v_t$.
+            self.adam_update(state, group, param, m, s + group['eps'])
         else:
-            # Perform *Rectified Adam* update
-            self.r_adam_update(state, group, param, m, s)
+            # Perform *Rectified Adam* update defined in [`radam.py`](radam.html), with
+            # $\color{cyan}{s_t} + \color{red}{\epsilon}$ in place of $v_t$.
+            self.r_adam_update(state, group, param, m, s + group['eps'])
